Actions, Resources, and Condition Keys for AWS Accounts - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Accounts.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

The AWS Documentation website is getting a new look!
Try it now and let us know what you think. Switch to the new look >>
You can return to the original look by selecting English in the language selector above.

# Actions, Resources, and Condition Keys for AWS Accounts

AWS Accounts (service prefix: `account`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS Accounts
- Resources Defined by AWS Accounts
- Condition Keys for AWS Accounts

## Actions Defined by AWS Accounts

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
DisableRegion | Grants permission to disable a region | Write |  | account:TargetRegion |
EnableRegion | Grants permission to enable a region | Write |  | account:TargetRegion |
ListRegions | Grants permission to list regions | List |  |  |

## Resources Defined by AWS Accounts

AWS Accounts does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to AWS Accounts, specify `“Resource”: “*”` in your policy.

## Condition Keys for AWS Accounts

AWS Accounts defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table.

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference.

Condition Keys | Description | Type
--- | --- | ---
account:TargetRegion | Filters access by a list of regions | String

On this page:

- Actions Defined by AWS Accounts
- Resources Defined by AWS Accounts
- Condition Keys for AWS Accounts

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more